import { Component, Prop, h, State, Host, Listen } from '@stencil/core';
import { Block, MintStatus } from '../../block';
import { getBlockExplorer } from '../../utils/utils';
import { handleNewAccount } from '../../utils/wallet-helper';
export class StructCore {
  constructor() {
    // Flag to enable testnet (rinkeby)
    this.testnet = false;
    // Wallet connect button text
    this.walletBtnText = 'Connect Wallet';
    // Mint button text
    this.mintBtnText = 'Mint';
    // Sold out text
    this.soldOutText = 'SOLD OUT!';
    this.isMinting = false;
    this.isConnecting = false;
    this.selectedAmount = 1;
    this.mint = async () => {
      try {
        this.isMinting = true;
        await this.block.mint(this.selectedAmount);
        this.isMinting = false;
      }
      catch (error) {
        console.log(error);
      }
    };
    this.initiateWallet = async () => {
      try {
        this.block = undefined;
        await window.ethereum
          .request({ method: 'eth_requestAccounts' })
          .then(async (accounts) => {
          this.isConnecting = true;
          const info = {};
          await handleNewAccount(accounts, info);
          this.block = await Block.create(this.contractAddress, this.testnet, this.type, info);
          this.initialized = true;
          this.isConnecting = false;
        })
          .catch(err => {
          console.log(err);
        });
      }
      catch (error) {
        console.log(error);
      }
    };
  }
  connectedCallback() {
    this.initiateWallet();
  }
  selectAmountChanged(event) {
    this.selectedAmount += event.detail;
  }
  updateTotalSupply(event) {
    this.block.totalSupply = this.block.totalSupply + event.detail;
    this.block = Object.assign({}, this.block);
  }
  render() {
    return (h(Host, { class: "wrapper" },
      !this.initialized && (h("wallet-button", { exportparts: "wallet-button", onClick: this.initiateWallet }, this.isConnecting ? 'Connecting...' : this.walletBtnText)),
      this.initialized && (h("div", { part: "container", class: "container" },
        h("mint-status", { "mint-status": this.block.status, exportparts: "status-bar" }),
        h("supply-display", { "personal-supply": this.block.personalAllocationLeft, "total-supply": this.block.totalSupply, "max-supply": this.block.maxSupply, exportparts: "supply-bar, supply-left" }),
        h("mint-config", { exportparts: "mint-input-group, mint-input-minus, mint-input-amount, mint-input-plus, mint-summary, mint-quantity", "mint-price": this.block.mintPrice, "selected-amount": this.selectedAmount, "max-amount": 2, "allocation-left": this.block.personalAllocationLeft }),
        h("div", { id: "message-box", part: "message-box" },
          this.block.message.error && h("p", { class: "error-message" }, this.block.message.error),
          this.block.message.info && h("p", null, this.block.message.info),
          this.block.message.transaction && (h("p", null,
            "View",
            ' ',
            h("a", { target: "_blank", rel: "noreferrer", href: `${getBlockExplorer(this.testnet)}/tx/${this.block.message.transaction}` }, "transaction")))),
        this.block.totalSupply !== this.block.maxSupply ? (h("mint-button", { exportparts: "mint-button", disabled: this.block.status === MintStatus.CLOSED || (this.block.status === MintStatus.PRIVATE && !this.block.walletSignature), onClick: () => this.mint() }, !this.isMinting ? `${this.mintBtnText}` : `Minting ${this.selectedAmount}...`)) : (h("p", { class: "sold-out", part: "sold-out" }, this.soldOutText)),
        h("div", { class: "contract-link", part: "contract-link" },
          h("a", { target: "_blank", rel: "noreferrer", href: `${getBlockExplorer(this.testnet)}/address/${this.contractAddress}` }, "View Contract"))))));
  }
  static get is() { return "struct-core"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["struct-core.sass"]
  }; }
  static get styleUrls() { return {
    "$": ["struct-core.css"]
  }; }
  static get properties() { return {
    "contractAddress": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "contract-address",
      "reflect": false
    },
    "testnet": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "testnet",
      "reflect": false,
      "defaultValue": "false"
    },
    "type": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ContractType",
        "resolved": "\"ERC1155\" | \"ERC721\"",
        "references": {
          "ContractType": {
            "location": "import",
            "path": "../../block"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "type",
      "reflect": false
    },
    "walletBtnText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "wallet-btn-text",
      "reflect": false,
      "defaultValue": "'Connect Wallet'"
    },
    "mintBtnText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "mint-btn-text",
      "reflect": false,
      "defaultValue": "'Mint'"
    },
    "soldOutText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "sold-out-text",
      "reflect": false,
      "defaultValue": "'SOLD OUT!'"
    }
  }; }
  static get states() { return {
    "initialized": {},
    "isMinting": {},
    "isConnecting": {},
    "selectedAmount": {}
  }; }
  static get listeners() { return [{
      "name": "amountChanged",
      "method": "selectAmountChanged",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}
