import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { f as formatEther, B as BigNumber } from './ethers.js';

const mintConfigCss = ":host{display:block}.summary{padding:1rem 0;border-top:1px solid var(--border-light, #6e7680);border-bottom:1px solid var(--border-light, #6e7680);display:flex;align-items:center;justify-content:space-between}.wrapper{display:flex;width:full;flex-direction:row;justify-content:space-between;padding:0.5rem 0;align-items:center;gap:0.5rem}.wrapper .input-group{align-items:center;display:flex;gap:1rem}.wrapper .input-group span{display:grid;place-items:center;height:2rem;width:2rem;border-radius:33px;border:1px solid var(--border-light, #6e7680)}button{display:flex;align-items:center;all:unset;font-size:1.5rem;cursor:pointer}button:disabled{opacity:0.5}";

const MintConfig = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.amountChanged = createEvent(this, "amountChanged", 7);
  }
  render() {
    return (h(Host, null, h("div", { id: "token-amount", class: "wrapper", part: "mint-quantity" }, h("span", null, "Quantity"), h("div", { class: "input-group", part: "mint-input-group" }, h("button", { part: "mint-input-minus", disabled: this.selectedAmount <= 1, type: "button", onClick: () => this.amountChanged.emit(-1) }, "\u2212"), h("span", { part: "mint-input-amount" }, this.selectedAmount), h("button", { part: "mint-input-plus", disabled: this.selectedAmount >= this.allocationLeft, type: "button", onClick: () => this.amountChanged.emit(1) }, "+")), h("span", null, this.allocationLeft, " Max")), h("div", { class: "summary", part: "mint-summary" }, h("span", null, "Total"), h("div", null, `${formatEther(BigNumber.from(this.mintPrice).mul(this.selectedAmount).toString())} ETH`, " + gas"))));
  }
  static get style() { return mintConfigCss; }
}, [1, "mint-config", {
    "selectedAmount": [2, "selected-amount"],
    "allocationLeft": [2, "allocation-left"],
    "mintPrice": [1, "mint-price"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mint-config"];
  components.forEach(tagName => { switch (tagName) {
    case "mint-config":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MintConfig);
      }
      break;
  } });
}

export { MintConfig as M, defineCustomElement as d };
