import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { h as handleNewAccount, B as Block, g as getBlockExplorer, a as MintStatus, d as defineCustomElement$4 } from './mint-status2.js';
import { d as defineCustomElement$6 } from './mint-button2.js';
import { d as defineCustomElement$5 } from './mint-config2.js';
import { d as defineCustomElement$3 } from './supply-display2.js';
import { d as defineCustomElement$2 } from './wallet-button2.js';

const structCoreCss = ":host{max-width:420px;background-color:var(--bg, #F8F8F8);border:1px solid var(--border-light, #6e7680);border-radius:10px;display:flex;flex-direction:column;font-family:\"Open Sans\", sans-serif}:host:first{width:full}:host a{color:#0E72ED;text-decoration:none}.contract-link{margin-top:1rem;text-align:center;text-transform:uppercase}.contract-link a{font-size:14px}.sold-out{border:1px solid var(--text, #222222);border-radius:8px;padding:13px 23px;text-align:center;font-weight:600}#message-box{width:100%;padding:0.75rem 0;display:block;height:20px;text-align:center}#message-box p{margin:0;text-align:center}.error-message{white-space:nowrap;overflow:hidden;text-overflow:ellipsis;color:#B10E2C}.container{padding:1rem}";

const StructCore$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    // Flag to enable testnet (rinkeby)
    this.testnet = false;
    // Wallet connect button text
    this.walletBtnText = 'Connect Wallet';
    // Mint button text
    this.mintBtnText = 'Mint';
    // Sold out text
    this.soldOutText = 'SOLD OUT!';
    this.isMinting = false;
    this.isConnecting = false;
    this.selectedAmount = 1;
    this.mint = async () => {
      try {
        this.isMinting = true;
        await this.block.mint(this.selectedAmount);
        this.isMinting = false;
      }
      catch (error) {
        console.log(error);
      }
    };
    this.initiateWallet = async () => {
      try {
        this.block = undefined;
        await window.ethereum
          .request({ method: 'eth_requestAccounts' })
          .then(async (accounts) => {
          this.isConnecting = true;
          const info = {};
          await handleNewAccount(accounts, info);
          this.block = await Block.create(this.contractAddress, this.testnet, this.type, info);
          this.initialized = true;
          this.isConnecting = false;
        })
          .catch(err => {
          console.log(err);
        });
      }
      catch (error) {
        console.log(error);
      }
    };
  }
  connectedCallback() {
    this.initiateWallet();
  }
  selectAmountChanged(event) {
    this.selectedAmount += event.detail;
  }
  updateTotalSupply(event) {
    this.block.totalSupply = this.block.totalSupply + event.detail;
    this.block = Object.assign({}, this.block);
  }
  render() {
    return (h(Host, { class: "wrapper" }, !this.initialized && (h("wallet-button", { exportparts: "wallet-button", onClick: this.initiateWallet }, this.isConnecting ? 'Connecting...' : this.walletBtnText)), this.initialized && (h("div", { part: "container", class: "container" }, h("mint-status", { "mint-status": this.block.status, exportparts: "status-bar" }), h("supply-display", { "personal-supply": this.block.personalAllocationLeft, "total-supply": this.block.totalSupply, "max-supply": this.block.maxSupply, exportparts: "supply-bar, supply-left" }), h("mint-config", { exportparts: "mint-input-group, mint-input-minus, mint-input-amount, mint-input-plus, mint-summary, mint-quantity", "mint-price": this.block.mintPrice, "selected-amount": this.selectedAmount, "max-amount": 2, "allocation-left": this.block.personalAllocationLeft }), h("div", { id: "message-box", part: "message-box" }, this.block.message.error && h("p", { class: "error-message" }, this.block.message.error), this.block.message.info && h("p", null, this.block.message.info), this.block.message.transaction && (h("p", null, "View", ' ', h("a", { target: "_blank", rel: "noreferrer", href: `${getBlockExplorer(this.testnet)}/tx/${this.block.message.transaction}` }, "transaction")))), this.block.totalSupply !== this.block.maxSupply ? (h("mint-button", { exportparts: "mint-button", disabled: this.block.status === MintStatus.CLOSED || (this.block.status === MintStatus.PRIVATE && !this.block.walletSignature), onClick: () => this.mint() }, !this.isMinting ? `${this.mintBtnText}` : `Minting ${this.selectedAmount}...`)) : (h("p", { class: "sold-out", part: "sold-out" }, this.soldOutText)), h("div", { class: "contract-link", part: "contract-link" }, h("a", { target: "_blank", rel: "noreferrer", href: `${getBlockExplorer(this.testnet)}/address/${this.contractAddress}` }, "View Contract"))))));
  }
  static get style() { return structCoreCss; }
}, [1, "struct-core", {
    "contractAddress": [1, "contract-address"],
    "testnet": [4],
    "type": [1],
    "walletBtnText": [1, "wallet-btn-text"],
    "mintBtnText": [1, "mint-btn-text"],
    "soldOutText": [1, "sold-out-text"],
    "initialized": [32],
    "isMinting": [32],
    "isConnecting": [32],
    "selectedAmount": [32]
  }, [[0, "amountChanged", "selectAmountChanged"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["struct-core", "mint-button", "mint-config", "mint-status", "supply-display", "wallet-button"];
  components.forEach(tagName => { switch (tagName) {
    case "struct-core":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, StructCore$1);
      }
      break;
    case "mint-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "mint-config":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "mint-status":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "supply-display":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "wallet-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const StructCore = StructCore$1;
const defineCustomElement = defineCustomElement$1;

export { StructCore, defineCustomElement };
